@@ -1,5 +1,5 @@
 /** @file exec/amfutil.c
- * 
+ *
  * Copyright (c) 2002-2005 MontaVista Software, Inc.
  * Author: Steven Dake (sdake@redhat.com)
  *
@@ -10,12 +10,12 @@
  * - Refactoring of code into several AMF files
  * - Serializers/deserializers
  *
- * Copyright (c) 2007-2008 Red Hat, Inc.
+ * Copyright (c) 2007-2009 Red Hat, Inc.
  *
  * All rights reserved.
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -39,14 +39,16 @@
  * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGE.
- * 
+ *
  * AMF utility functions
- * 
+ *
  * This file contains functions that provide different services used by other
  * AMF files. For example parsing the configuration file, printing state etc.
- * 
+ *
  */
 
+#include <config.h>
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -55,7 +57,10 @@
 #include <regex.h>
 #include <netinet/in.h>
 
-#include <corosync/ipc_gen.h>
+#include <corosync/corotypes.h>
+#include <corosync/coroipc_types.h>
+#include <corosync/coroipcc.h>
+#include <corosync/corodefs.h>
 #include <corosync/mar_gen.h>
 #include <corosync/engine/coroapi.h>
 #include <corosync/list.h>
@@ -66,7 +71,7 @@
 #include "ipc_amf.h"
 #include "amf.h"
 
-LOGSYS_DECLARE_SUBSYS ("AMF", LOG_INFO);
+LOGSYS_DECLARE_SUBSYS ("AMF");
 
 #ifndef COROSYNC_CLUSTER_STARTUP_TIMEOUT
 #define COROSYNC_CLUSTER_STARTUP_TIMEOUT 5000
@@ -75,7 +80,7 @@ LOGSYS_DECLARE_SUBSYS ("AMF", LOG_INFO);
 extern char *strstr_rs (const char *haystack, const char *needle);
 
 struct req_exec_amf_msg {
-	mar_req_header_t header;
+	coroipc_request_header_t header;
 };
 
 static const char *presence_state_text[] = {
@@ -152,6 +157,13 @@ char *strstr_rs (const char *haystack, const char *needle)
 	return (end_address);
 }
 
+void amfutil_init (void)
+{
+#ifdef OPENAIS_SOLARIS
+	logsys_subsys_init ();
+#endif
+}
+
 static int init_category (struct amf_comp *comp, char *loc)
 {
 	if (strcmp (loc, "sa_aware") == 0) {
@@ -167,7 +179,7 @@ static int init_category (struct amf_comp *comp, char *loc)
 	}
 
 	return 0;
-}   
+}
 
 static int init_capability (struct amf_comp *comp, char *loc)
 {
@@ -275,7 +287,7 @@ struct amf_cluster *amf_config_read (char **error_string)
 	char buf[1024];
 	char *line;
 	FILE *fp;
-	char *filename;
+	const char *filename;
 	amf_object_type_t current_parse = AMF_NONE;
 	int line_number = 0;
 	char *loc;
@@ -299,11 +311,11 @@ struct amf_cluster *amf_config_read (char **error_string)
 	int                       comp_cs_type_cnt = 0;
 	int                       csi_attr_cnt = 0;
 	int                       csi_dependencies_cnt = 0;
-	char                     *error_reason = NULL;
+	const char                *error_reason = NULL;
 	char                     *value;
 	filename = getenv ("COROSYNC_AMF_CONFIG_FILE");
 	if (!filename) {
-		filename = "/etc/ais/amf.conf";
+		filename = COROSYSCONFDIR "/amf.conf";
 	}
 
 	fp = fopen (filename, "r");
@@ -320,7 +332,9 @@ struct amf_cluster *amf_config_read (char **error_string)
 	while (fgets (buf, 255, fp)) {
 		line_number += 1;
 		line = buf;
-		line[strlen(line) - 1] = '\0';
+		if (strlen(line) > 0) {
+			line[strlen(line) - 1] = '\0';
+		}
 		/*
 		 * Clear out comments and empty lines
 		 */
@@ -916,16 +930,16 @@ parse_error:
 static void print_csi_assignment (struct amf_comp *comp,
 	struct amf_csi_assignment *csi_assignment)
 {
-	log_printf (LOG_INFO, "            safCSI=%s\n", csi_assignment->csi->name.value);
-	log_printf (LOG_INFO, "              HA state: %s\n",
+	log_printf (LOGSYS_LEVEL_INFO, "            safCSI=%s\n", csi_assignment->csi->name.value);
+	log_printf (LOGSYS_LEVEL_INFO, "              HA state: %s\n",
 		ha_state_text[csi_assignment->saAmfCSICompHAState]);
 }
 
 static void print_si_assignment (struct amf_su *su,
 	struct amf_si_assignment *si_assignment)
 {
-	log_printf (LOG_INFO, "          safSi=%s\n", si_assignment->si->name.value);
-	log_printf (LOG_INFO, "            HA state: %s\n",
+	log_printf (LOGSYS_LEVEL_INFO, "          safSi=%s\n", si_assignment->si->name.value);
+	log_printf (LOGSYS_LEVEL_INFO, "            HA state: %s\n",
 		ha_state_text[si_assignment->saAmfSISUHAState]);
 }
 
@@ -939,100 +953,100 @@ void amf_runtime_attributes_print (struct amf_cluster *cluster)
 	struct amf_si *si;
 	struct amf_csi *csi;
 
-	log_printf (LOG_INFO, "AMF runtime attributes:");
-	log_printf (LOG_INFO, "===================================================");
-	log_printf (LOG_INFO, "safCluster=%s", getSaNameT(&cluster->name));
-	log_printf (LOG_INFO, "  admin state: %s\n",
+	log_printf (LOGSYS_LEVEL_INFO, "AMF runtime attributes:");
+	log_printf (LOGSYS_LEVEL_INFO, "===================================================");
+	log_printf (LOGSYS_LEVEL_INFO, "safCluster=%s", getSaNameT(&cluster->name));
+	log_printf (LOGSYS_LEVEL_INFO, "  admin state: %s\n",
 		admin_state_text[cluster->saAmfClusterAdminState]);
-	log_printf (LOG_INFO, "  state:       %u\n", cluster->acsm_state);
+	log_printf (LOGSYS_LEVEL_INFO, "  state:       %u\n", cluster->acsm_state);
 	for (node = cluster->node_head; node != NULL; node = node->next) {
-		log_printf (LOG_INFO, "  safNode=%s\n", getSaNameT (&node->name));
-		log_printf (LOG_INFO, "    CLM Node:    %s\n", getSaNameT (&node->saAmfNodeClmNode));
-		log_printf (LOG_INFO, "    node ID:     %u\n", node->nodeid);
-		log_printf (LOG_INFO, "    admin state: %s\n",
+		log_printf (LOGSYS_LEVEL_INFO, "  safNode=%s\n", getSaNameT (&node->name));
+		log_printf (LOGSYS_LEVEL_INFO, "    CLM Node:    %s\n", getSaNameT (&node->saAmfNodeClmNode));
+		log_printf (LOGSYS_LEVEL_INFO, "    node ID:     %u\n", node->nodeid);
+		log_printf (LOGSYS_LEVEL_INFO, "    admin state: %s\n",
 			admin_state_text[node->saAmfNodeAdminState]);
-		log_printf (LOG_INFO, "    oper state:  %s\n",
+		log_printf (LOGSYS_LEVEL_INFO, "    oper state:  %s\n",
 			oper_state_text[node->saAmfNodeOperState]);
-		log_printf (LOG_INFO, "    acsm state:  %u\n", node->acsm_state);
+		log_printf (LOGSYS_LEVEL_INFO, "    acsm state:  %u\n", node->acsm_state);
 	}
 	for (app = cluster->application_head; app != NULL; app = app->next) {
-		log_printf (LOG_INFO, "  safApp=%s\n", getSaNameT(&app->name));
-		log_printf (LOG_INFO, "    admin state: %s\n",
+		log_printf (LOGSYS_LEVEL_INFO, "  safApp=%s\n", getSaNameT(&app->name));
+		log_printf (LOGSYS_LEVEL_INFO, "    admin state: %s\n",
 			admin_state_text[app->saAmfApplicationAdminState]);
-		log_printf (LOG_INFO, "    num_sg:      %d\n", app->saAmfApplicationCurrNumSG);
+		log_printf (LOGSYS_LEVEL_INFO, "    num_sg:      %d\n", app->saAmfApplicationCurrNumSG);
 		for (sg = app->sg_head; sg != NULL; sg = sg->next) {
-			log_printf (LOG_INFO, "    safSg=%s\n", getSaNameT(&sg->name));
-			log_printf (LOG_INFO, "      avail_state:        %u\n",
+			log_printf (LOGSYS_LEVEL_INFO, "    safSg=%s\n", getSaNameT(&sg->name));
+			log_printf (LOGSYS_LEVEL_INFO, "      avail_state:        %u\n",
 				sg->avail_state);
-			log_printf (LOG_INFO, "      admin state:        %s\n",
+			log_printf (LOGSYS_LEVEL_INFO, "      admin state:        %s\n",
 				admin_state_text[sg->saAmfSGAdminState]);
-			log_printf (LOG_INFO, "      assigned SUs        %d\n",
+			log_printf (LOGSYS_LEVEL_INFO, "      assigned SUs        %d\n",
 				sg->saAmfSGNumCurrAssignedSUs);
-			log_printf (LOG_INFO, "      non inst. spare SUs %d\n",
+			log_printf (LOGSYS_LEVEL_INFO, "      non inst. spare SUs %d\n",
 				sg->saAmfSGNumCurrNonInstantiatedSpareSUs);
-			log_printf (LOG_INFO, "      inst. spare SUs     %d\n",
+			log_printf (LOGSYS_LEVEL_INFO, "      inst. spare SUs     %d\n",
 				sg->saAmfSGNumCurrInstantiatedSpareSUs);
 			for (su = sg->su_head; su != NULL; su = su->next) {
-				log_printf (LOG_INFO, "      safSU=%s\n", getSaNameT(&su->name));
-				log_printf (LOG_INFO, "        oper state:      %s\n",
+				log_printf (LOGSYS_LEVEL_INFO, "      safSU=%s\n", getSaNameT(&su->name));
+				log_printf (LOGSYS_LEVEL_INFO, "        oper state:      %s\n",
 					oper_state_text[su->saAmfSUOperState]);
-				log_printf (LOG_INFO, "        admin state:     %s\n",
+				log_printf (LOGSYS_LEVEL_INFO, "        admin state:     %s\n",
 					admin_state_text[su->saAmfSUAdminState]);
-				log_printf (LOG_INFO, "        readiness state: %s\n",
+				log_printf (LOGSYS_LEVEL_INFO, "        readiness state: %s\n",
 					readiness_state_text[amf_su_get_saAmfSUReadinessState (su)]);
-				log_printf (LOG_INFO, "        presence state:  %s\n",
+				log_printf (LOGSYS_LEVEL_INFO, "        presence state:  %s\n",
 					presence_state_text[su->saAmfSUPresenceState]);
-				log_printf (LOG_INFO, "        hosted by node   %s\n",
+				log_printf (LOGSYS_LEVEL_INFO, "        hosted by node   %s\n",
 					su->saAmfSUHostedByNode.value);
-				log_printf (LOG_INFO, "        num active SIs   %d\n",
+				log_printf (LOGSYS_LEVEL_INFO, "        num active SIs   %d\n",
 					amf_su_get_saAmfSUNumCurrActiveSIs (su));
-				log_printf (LOG_INFO, "        num standby SIs  %d\n",
+				log_printf (LOGSYS_LEVEL_INFO, "        num standby SIs  %d\n",
 					amf_su_get_saAmfSUNumCurrStandbySIs (su));
-				log_printf (LOG_INFO, "        restart count    %d\n",
+				log_printf (LOGSYS_LEVEL_INFO, "        restart count    %d\n",
 					su->saAmfSURestartCount);
-				log_printf (LOG_INFO, "        restart control state %d\n",
+				log_printf (LOGSYS_LEVEL_INFO, "        restart control state %d\n",
 					su->restart_control_state);
-				log_printf (LOG_INFO, "        SU failover cnt  %d\n", su->su_failover_cnt);
-				log_printf (LOG_INFO, "        assigned SIs:");
+				log_printf (LOGSYS_LEVEL_INFO, "        SU failover cnt  %d\n", su->su_failover_cnt);
+				log_printf (LOGSYS_LEVEL_INFO, "        assigned SIs:");
 				amf_su_foreach_si_assignment (su, print_si_assignment);
 
 				for (comp = su->comp_head; comp != NULL; comp = comp->next) {
-					log_printf (LOG_INFO, "        safComp=%s\n", getSaNameT(&comp->name));
-					log_printf (LOG_INFO, "          oper state:      %s\n",
+					log_printf (LOGSYS_LEVEL_INFO, "        safComp=%s\n", getSaNameT(&comp->name));
+					log_printf (LOGSYS_LEVEL_INFO, "          oper state:      %s\n",
 						oper_state_text[comp->saAmfCompOperState]);
-					log_printf (LOG_INFO, "          readiness state: %s\n",
+					log_printf (LOGSYS_LEVEL_INFO, "          readiness state: %s\n",
 						readiness_state_text[amf_comp_get_saAmfCompReadinessState (comp)]);
-					log_printf (LOG_INFO, "          presence state:  %s\n",
+					log_printf (LOGSYS_LEVEL_INFO, "          presence state:  %s\n",
 						presence_state_text[comp->saAmfCompPresenceState]);
-					log_printf (LOG_INFO, "          num active CSIs  %d\n",
+					log_printf (LOGSYS_LEVEL_INFO, "          num active CSIs  %d\n",
 						amf_comp_get_saAmfCompNumCurrActiveCsi (comp));
-					log_printf (LOG_INFO, "          num standby CSIs %d\n",
+					log_printf (LOGSYS_LEVEL_INFO, "          num standby CSIs %d\n",
 						amf_comp_get_saAmfCompNumCurrStandbyCsi (comp));
-					log_printf (LOG_INFO, "          restart count    %d\n",
+					log_printf (LOGSYS_LEVEL_INFO, "          restart count    %d\n",
 						comp->saAmfCompRestartCount);
-					log_printf (LOG_INFO, "          assigned CSIs:");
+					log_printf (LOGSYS_LEVEL_INFO, "          assigned CSIs:");
 					amf_comp_foreach_csi_assignment (
 						comp, print_csi_assignment);
 				}
 			}
 		}
 		for (si = app->si_head; si != NULL; si = si->next) {
-			log_printf (LOG_INFO, "    safSi=%s\n", getSaNameT(&si->name));
-			log_printf (LOG_INFO, "      admin state:         %s\n",
+			log_printf (LOGSYS_LEVEL_INFO, "    safSi=%s\n", getSaNameT(&si->name));
+			log_printf (LOGSYS_LEVEL_INFO, "      admin state:         %s\n",
 				admin_state_text[si->saAmfSIAdminState]);
-			log_printf (LOG_INFO, "      assignm. state:      %s\n",
+			log_printf (LOGSYS_LEVEL_INFO, "      assignm. state:      %s\n",
 				assignment_state_text[
 				amf_si_get_saAmfSIAssignmentState (si)]);
-			log_printf (LOG_INFO, "      active assignments:  %d\n",
+			log_printf (LOGSYS_LEVEL_INFO, "      active assignments:  %d\n",
 				amf_si_get_saAmfSINumCurrActiveAssignments (si));
-			log_printf (LOG_INFO, "      standby assignments: %d\n",
+			log_printf (LOGSYS_LEVEL_INFO, "      standby assignments: %d\n",
 				amf_si_get_saAmfSINumCurrStandbyAssignments (si));
 			for (csi = si->csi_head; csi != NULL; csi = csi->next) {
-				log_printf (LOG_INFO, "      safCsi=%s\n", getSaNameT(&csi->name));
+				log_printf (LOGSYS_LEVEL_INFO, "      safCsi=%s\n", getSaNameT(&csi->name));
 			}
 		}
 	}
-	log_printf (LOG_INFO, "===================================================");
+	log_printf (LOGSYS_LEVEL_INFO, "===================================================");
 }
 
 /* to be removed... */
@@ -1250,7 +1264,7 @@ void *_amf_malloc (size_t size, const char *file, unsigned int line)
 	void *tmp = malloc (size);
 
 	if (tmp == NULL) {
-		log_printf (LOG_LEVEL_ERROR, "AMF out-of-memory at %s:%u", file, line);
+		log_printf (LOGSYS_LEVEL_ERROR, "AMF out-of-memory at %s:%u", file, line);
 		api->error_memory_failure ();
 	}
 
@@ -1262,7 +1276,7 @@ void *_amf_calloc (size_t nmemb, size_t size, const char *file, unsigned int lin
 	void *tmp = calloc (nmemb, size);
 
 	if (tmp == NULL) {
-		log_printf (LOG_LEVEL_ERROR, "AMF out-of-memory at %s:%u", file, line);
+		log_printf (LOGSYS_LEVEL_ERROR, "AMF out-of-memory at %s:%u", file, line);
 		api->error_memory_failure ();
 	}
 
@@ -1274,7 +1288,7 @@ void *_amf_realloc (void* ptr, size_t size, const char *file, unsigned int line)
 	void *tmp = realloc (ptr, size);
 
 	if (tmp == NULL) {
-		log_printf (LOG_LEVEL_ERROR, "AMF out-of-memory at %s:%u", file, line);
+		log_printf (LOGSYS_LEVEL_ERROR, "AMF out-of-memory at %s:%u", file, line);
 		api->error_memory_failure ();
 	}
 
@@ -1286,14 +1300,15 @@ char *_amf_strdup (const char *in_str, const char *file, unsigned int line)
 	char *out_str = strdup (in_str);
 
 	if (out_str == NULL) {
-		log_printf (LOG_LEVEL_ERROR, "AMF out-of-memory at %s:%u", file, line);
+		log_printf (LOGSYS_LEVEL_ERROR, "AMF out-of-memory at %s:%u", file, line);
 		api->error_memory_failure ();
 	}
 
 	return out_str;
 }
 
-int sa_amf_grep_one_sub_match(const char *string, char *pattern, 
+#ifdef TODO
+static int sa_amf_grep_one_sub_match(const char *string, char *pattern,
 	SaNameT *matches_arr)
 {
 	int             status;
@@ -1322,7 +1337,7 @@ int sa_amf_grep_one_sub_match(const char *string, char *pattern,
 			sub_string_len = pmatch[i].rm_eo - pmatch[i].rm_so;
 			if (i==1) {
 
-				memcpy(matches_arr[i].value, string + pmatch[i].rm_so, 
+				memcpy(matches_arr[i].value, string + pmatch[i].rm_so,
 					sub_string_len);
 				matches_arr[i].value[sub_string_len] = '\0';
 			}
@@ -1334,9 +1349,10 @@ int sa_amf_grep_one_sub_match(const char *string, char *pattern,
 	return status;
 
 }
+#endif
 
 
-int sa_amf_grep(const char *string, char *pattern, size_t nmatch,
+int sa_amf_grep(const char *string, const char *pattern, size_t nmatch,
 	SaNameT *matches_arr)
 {
 	int             status;
@@ -1360,8 +1376,8 @@ int sa_amf_grep(const char *string, char *pattern, size_t nmatch,
 
 		for (i = 0; i < nmatch; i++) {
 			int sub_string_len;
-			sub_string_len = pmatch[i].rm_eo - pmatch[i].rm_so; 
-			memcpy(matches_arr[i].value, string + pmatch[i].rm_so, 
+			sub_string_len = pmatch[i].rm_eo - pmatch[i].rm_so;
+			memcpy(matches_arr[i].value, string + pmatch[i].rm_so,
 				sub_string_len);
 			matches_arr[i].value[sub_string_len] = '\0';
 			matches_arr[i].length = sub_string_len;
@@ -1380,7 +1396,7 @@ out:
  * @param msg_id
  * @param buf
  * @param len
- * 
+ *
  * @return int
  */
 int amf_msg_mcast (int msg_id, void *buf, size_t len)
@@ -1417,7 +1433,7 @@ int amf_msg_mcast (int msg_id, void *buf, size_t len)
 	return res;
 }
 
-void amf_fifo_put (int entry_type, amf_fifo_t **root, int size_of_data, 
+void amf_fifo_put (int entry_type, amf_fifo_t **root, int size_of_data,
 	void *data)
 {
 	amf_fifo_t *fifo;
@@ -1427,11 +1443,11 @@ void amf_fifo_put (int entry_type, amf_fifo_t **root, int size_of_data,
 	for (fifo = *root; fifo != NULL; fifo = fifo->next) {
 		if (fifo->next == NULL) {
 			new_item = &fifo->next;
-		}		
+		}
 	}
 	*new_item = amf_malloc (size_of_data + sizeof (amf_fifo_t));
 	fifo = *new_item;
-	
+
 	/* Set data of this entry*/
 	fifo->entry_type = entry_type;
 	fifo->next = NULL;
@@ -1462,17 +1478,16 @@ int amf_fifo_get (amf_fifo_t **root, void *data)
  * execution in this thread has been re-assumed because of a
  * time-out. Time-out time is 0 msec so f will be called as soon
  * as possible. *
- * 
+ *
  * @param async_func
  * @param func_param
  */
 
 void amf_call_function_asynchronous (async_func_t async_func, void *func_param)
 {
-	
+
 	static corosync_timer_handle_t async_func_timer_handle;
 	api->timer_add_duration (
-		0, func_param, async_func, 
+		0, func_param, async_func,
 		&async_func_timer_handle);
 }
-
